import os
import json
import logging

from datetime import timedelta, datetime

from cachetools import lru_cache
from flask import (abort, redirect, request, url_for, make_response, Response, render_template,
                   Blueprint, jsonify, send_file, session)
from flask_login import current_user


from app import (app)
from endpoints.api.discovery import swagger_route_data
from endpoints.common import common_login, render_page_template
from util.cache import no_cache



@lru_cache(maxsize=1)
def _get_route_data():
    return swagger_route_data(include_internal=True, compact=True)


def render_page_template_with_routedata(name, *args, **kwargs):
    return render_page_template(name, _get_route_data(), *args, **kwargs)

# Capture the unverified SSL errors.
logger = logging.getLogger(__name__)
logging.captureWarnings(True)

setup_web = Blueprint('setup_web', __name__, template_folder='templates')

STATUS_TAGS = app.config['STATUS_TAGS']

@setup_web.route('/', methods=['GET'], defaults={'path': ''})
@no_cache
def index(path, **kwargs):
    return render_page_template_with_routedata('config_index.html', js_bundle_name='configapp', **kwargs)

@setup_web.errorhandler(404)
@setup_web.route('/404', methods=['GET'])
def not_found_error_display(e = None):
    resp = index('', error_code=404, error_info=dict(reason='notfound'))
    resp.status_code = 404
    return resp
